@@ -1,4 +1,6 @@
 from .main import Wallex
+from .websocket import WallexWebsocket
+
 from . import exceptions
 
 from ._deprecated import Wallex as WallexDeprecated
@@ -8,5 +10,6 @@ from ._package_data import __version__
 
 __all__ = [
     'Wallex',
+    'WallexWebsocket',
     'exceptions',
 ]
